@@ -5,204 +5,214 @@ use base 'WebService::GData';
 use WebService::GData::Base;
 use WebService::GData::YouTube::Constants;
 use WebService::GData::YouTube::Query;
+
+#TODO: load these packages on demand
 use WebService::GData::YouTube::Feed;
 use WebService::GData::YouTube::Feed::PlaylistLink;
 use WebService::GData::YouTube::Feed::Video;
+use WebService::GData::YouTube::Feed::Comment;
+
+
 our $PROJECTION = WebService::GData::YouTube::Constants::PROJECTION;
 our $BASE_URI   = WebService::GData::YouTube::Constants::BASE_URI;
-our $VERSION    = 0.01_07;
+
+our $VERSION    = 0.01_08;
 
 sub __init {
-    my ( $this, $auth ) = @_;
+	my ( $this, $auth ) = @_;
 
-    $this->{_baseuri} = $BASE_URI . $PROJECTION . '/';
-    $this->{_request}    = new WebService::GData::Base();
-    $this->{_request}->auth($auth) if ($auth);
+	$this->{_baseuri} = $BASE_URI . $PROJECTION . '/';
+	$this->{_request} = new WebService::GData::Base();
+	$this->{_request}->auth($auth) if ($auth);
 
-    #overwrite default query engine to support youtube extra feature
-    my $query = new WebService::GData::YouTube::Query();
-    $query->key( $auth->key ) if ($auth);
-    $this->query($query);
+	#overwrite default query engine to support youtube extra feature
+	my $query = new WebService::GData::YouTube::Query();
+	$query->key( $auth->key ) if ($auth);
+	$this->query($query);
 }
 
 sub query {
-    my ( $this, $query ) = @_;
-    return $this->{_request}->query($query);
+	my ( $this, $query ) = @_;
+	return $this->{_request}->query($query);
 }
 
 sub base_uri {
-    my $this = shift;
-    return $this->{_baseuri};
+	my $this = shift;
+	return $this->{_baseuri};
 }
 
 sub base_query {
-    my $this = shift;
-    return $this->query->to_query_string;
+	my $this = shift;
+	return $this->query->to_query_string;
 }
 
 #playlist related
 
 sub get_user_playlist_by_id {
-    my ( $this, $playlistid, $full ) = @_;
+	my ( $this, $playlistid, $full ) = @_;
 
-    my $res =
-      $this->{_request}->get( $this->{_baseuri} . 'playlists/' . $playlistid );
+	my $res =
+	  $this->{_request}->get( $this->{_baseuri} . 'playlists/' . $playlistid );
 
-    my $playlists =
-      new WebService::GData::YouTube::Feed( $res, $this->{_request} );
+	my $playlists =
+	  new WebService::GData::YouTube::Feed( $res, $this->{_request} );
 
-    return $playlists if ($full);
+	return $playlists if ($full);
 
-    return $playlists->entry->[0];
+	return $playlists->entry->[0];
 }
 
 sub get_user_playlists {
-    my ( $this, $channel, $full ) = @_;
+	my ( $this, $channel, $full ) = @_;
 
-    #by default, the one connected is returned
-    my $uri = $this->{_baseuri} . 'users/default/playlists';
-    $uri = $this->{_baseuri} . 'users/' . $channel . '/playlists' if ($channel);
+	#by default, the one connected is returned
+	my $uri = $this->{_baseuri} . 'users/default/playlists';
+	$uri = $this->{_baseuri} . 'users/' . $channel . '/playlists' if ($channel);
 
-    my $res = $this->{_request}->get($uri);
+	my $res = $this->{_request}->get($uri);
 
-    my $playlists =
-      new WebService::GData::YouTube::Feed( $res, $this->{_request} );
+	my $playlists =
+	  new WebService::GData::YouTube::Feed( $res, $this->{_request} );
 
-    return $playlists if ($full);
+	return $playlists if ($full);
 
-    return $playlists->entry;
+	return $playlists->entry;
 }
 
 #video related
 
 sub video {
+	my $this = shift;
+	return new WebService::GData::YouTube::Feed::Video( $this->{_request} );
+}
+
+sub playlists {
     my $this = shift;
-    return new WebService::GData::YouTube::Feed::Video($this->{_request});
+    return new WebService::GData::YouTube::Feed::PlaylistLink( $this->{_request} );
 }
 
 sub comment {
-    my $this = shift;
-    return new WebService::GData::YouTube::Feed::Comment($this->{_request});
+	my $this = shift;
+	return new WebService::GData::YouTube::Feed::Comment( $this->{_request} );
 }
 
 sub search_video {
-    my ( $this, $query ) = @_;
-    $this->query($query) if ($query);
-    my $res = $this->{_request}->get( $this->{_baseuri} . 'videos/' );
-    my $playlists =
-      new WebService::GData::YouTube::Feed( $res, $this->{_request} );
-    return $playlists->entry;
+	my ( $this, $query ) = @_;
+	$this->query($query) if ($query);
+	my $res = $this->{_request}->get( $this->{_baseuri} . 'videos/' );
+	my $playlists =
+	  new WebService::GData::YouTube::Feed( $res, $this->{_request} );
+	return $playlists->entry;
 }
 
 sub get_video_by_id {
-    my ( $this, $id ) = @_;
+	my ( $this, $id ) = @_;
 
-    my $uri = $this->{_baseuri} . 'videos/' . $id;
+	my $uri = $this->{_baseuri} . 'videos/' . $id;
 
-    my $res = $this->{_request}->get($uri);
+	my $res = $this->{_request}->get($uri);
 
-    my $playlists =
-      new WebService::GData::YouTube::Feed( $res, $this->{_request} );
+	my $playlists =
+	  new WebService::GData::YouTube::Feed( $res, $this->{_request} );
 
-    return $playlists->entry->[0];
+	return $playlists->entry->[0];
 }
 
 sub get_user_video_by_id {
-    my ( $this, $id, $channel ) = @_;
+	my ( $this, $id, $channel ) = @_;
 
-    my $uri = $this->{_baseuri} . 'users/default/uploads/' . $id;
-    $uri = $this->{_baseuri} . 'users/' . $channel . '/uploads/' . $id
-      if ($channel);
+	my $uri = $this->{_baseuri} . 'users/default/uploads/' . $id;
+	$uri = $this->{_baseuri} . 'users/' . $channel . '/uploads/' . $id
+	  if ($channel);
 
-    my $res = $this->{_request}->get($uri);
+	my $res = $this->{_request}->get($uri);
 
-    my $playlists =
-      new WebService::GData::YouTube::Feed( $res, $this->{_request} );
+	my $playlists =
+	  new WebService::GData::YouTube::Feed( $res, $this->{_request} );
 
-    return $playlists->entry->[0];
+	return $playlists->entry->[0];
 }
 
 sub get_user_videos {
-    my ( $this, $channel ) = @_;
+	my ( $this, $channel ) = @_;
 
-    my $uri = $this->{_baseuri} . 'users/default/uploads';
-    $uri = $this->{_baseuri} . 'users/' . $channel . '/uploads' if ($channel);
+	my $uri = $this->{_baseuri} . 'users/default/uploads';
+	$uri = $this->{_baseuri} . 'users/' . $channel . '/uploads' if ($channel);
 
-    my $res = $this->{_request}->get($uri);
+	my $res = $this->{_request}->get($uri);
 
-    my $playlists =
-      new WebService::GData::YouTube::Feed( $res, $this->{_request} );
+	my $playlists =
+	  new WebService::GData::YouTube::Feed( $res, $this->{_request} );
 
-    return $playlists->entry;
+	return $playlists->entry;
 }
 
 sub get_user_favorite_videos {
-    my ( $this, $channel ) = @_;
+	my ( $this, $channel ) = @_;
 
-    my $uri = $this->{_baseuri} . 'users/default/favorites/';
-    $uri = $this->{_baseuri} . 'users/' . $channel . '/favorites/'
-      if ($channel);
+	my $uri = $this->{_baseuri} . 'users/default/favorites/';
+	$uri = $this->{_baseuri} . 'users/' . $channel . '/favorites/'
+	  if ($channel);
 
-    my $res = $this->{_request}->get($uri);
+	my $res = $this->{_request}->get($uri);
 
-    my $playlists =
-      new WebService::GData::YouTube::Feed( $res, $this->{_request} );
+	my $playlists =
+	  new WebService::GData::YouTube::Feed( $res, $this->{_request} );
 
-    return $playlists->entry;
+	return $playlists->entry;
 }
 
 sub move_video {
-    my ( $this, %params ) = @_;
+	my ( $this, %params ) = @_;
 
-    my $playlistLink =
-      new WebService::GData::YouTube::Feed::PlaylistLink( {}, $this->{_request} );
+	my $playlistLink =
+	  new WebService::GData::YouTube::Feed::PlaylistLink( {},
+		$this->{_request} );
 
-    #delete old one
-    $playlistLink->playlistId( $params{'from'} );
-    $playlistLink->deleteVideo( videoId => $params{'videoid'} );
+	#delete old one
+	$playlistLink->playlistId( $params{'from'} );
+	$playlistLink->deleteVideo( videoId => $params{'videoid'} );
 
-    #put in new one
-    $playlistLink->playlistId( $params{'to'} );
-    $playlistLink->addVideo( videoId => $params{'videoid'} );
+	#put in new one
+	$playlistLink->playlistId( $params{'to'} );
+	$playlistLink->addVideo( videoId => $params{'videoid'} );
 }
 
 #standard feeds
 no strict 'refs';
 foreach my $stdfeed (
-    qw(top_rated top_favorites most_viewed most_popular most_recent most_discussed most_responded recently_featured watch_on_mobile)
+	qw(top_rated top_favorites most_viewed most_popular most_recent most_discussed most_responded recently_featured watch_on_mobile)
   )
 {
 
-    *{ __PACKAGE__ . '::get_' . $stdfeed . '_videos' } = sub {
-        my ( $this, $region, $category, $time ) = @_;
+	*{ __PACKAGE__ . '::get_' . $stdfeed . '_videos' } = sub {
+		my ( $this, $region, $category, $time ) = @_;
 
-        my $uri = $this->{_baseuri} . 'standardfeeds/';
-        $uri .= $region . '/'   if ($region);
-        $uri .= $stdfeed;
-        $uri .= '_' . $category if ($category);
-        $this->query->time($time) if ($time);
-        my $res = $this->{_request}->get($uri);
+		my $uri = $this->{_baseuri} . 'standardfeeds/';
+		$uri .= $region . '/' if $region;
+		$uri .= $stdfeed;
+		$uri .= '_' . $category if $category;
+		$this->query->time($time) if $time;
+		my $res = $this->{_request}->get($uri);
 
-        my $playlists =
-          new WebService::GData::YouTube::Feed( $res, $this->{_request} );
-        return $playlists->entry;
-      }
+		my $playlists =
+		  new WebService::GData::YouTube::Feed( $res, $this->{_request} );
+		return $playlists->entry;
+	  }
 }
 
-#to do: comments returns comments feeds! responses,related sends back video feed so are ok!
 foreach my $feed (qw(comments responses related)) {
 
-    *{ __PACKAGE__ . '::get_' . $feed . '_for_video_id' } = sub {
-        my ( $this, $id ) = @_;
+	*{ __PACKAGE__ . '::get_' . $feed . '_for_video_id' } = sub {
+		my ( $this, $id ) = @_;
 
-        my $uri = $this->{_baseuri} . 'videos/' . $id . '/' . $feed;
-        my $res = $this->{_request}->get($uri);
+		my $uri = $this->{_baseuri} . 'videos/' . $id . '/' . $feed;
+		my $res = $this->{_request}->get($uri);
 
-        my $playlists =
-          new WebService::GData::YouTube::Feed( $res, $this->{_request} )
-          ;
-        return $playlists->entry;
-      }
+		my $playlists =
+		  new WebService::GData::YouTube::Feed( $res, $this->{_request} );
+		return $playlists->entry;
+	  }
 }
 
 "The earth is blue like an orange.";
@@ -271,10 +281,14 @@ WebService::GData::YouTube - Access YouTube contents(read/write) with API v2.
 
 
 !DEVELOPER RELEASE! API may change, program may break or be under optimized.
+
 !DEVELOPER RELEASE! API may change, program may break or be under optimized.
+
 !DEVELOPER RELEASE! API may change, program may break or be under optimized.
+
 !WARNING! Documentation in progress.
 
+
 I<inherits from L<WebService::GData>>
 
 This package is a point of entry giving access to general YouTube feeds.
@@ -288,6 +302,10 @@ Most of the methods will return one of the following object:
 
 This object handles the manipulation of the video data such as inserting/editing the metadata, uploading a video,etc.
 
+=item L<WebService::GData::YouTube::Feed::Comment>
+
+This object handles the insertion of comments on a video or in reply to an other comment.
+
 =item L<WebService::GData::YouTube::Feed::Playlist>
 
 This object inherits from L<WebService::GData::YouTube::Feed::Video>.
@@ -874,30 +892,23 @@ Example:
 =back
 
 
-
-
-
-
-
-
-
 =head2 FACTORY METHODS
 
+=over
+
 These methods instantiate YouTube::Feed::* packages. It just saves some typing.
 
 =head3 video
 
-=over
-  Return a L<WebService::GData::YouTube::Feed::Video> instance
+Return a L<WebService::GData::YouTube::Feed::Video> instance
  
-=back
-
 =head3 comment
 
-=over
-  Return a L<WebService::GData::YouTube::Feed::Comment> instance
+Return a L<WebService::GData::YouTube::Feed::Comment> instance
+
+=head3 playlists
  
-=back
+Return a L<WebService::GData::YouTube::Feed::PlaylistLink> instance
 
 Example:
     
@@ -906,7 +917,7 @@ Example:
     my $auth; 
     eval {
         $auth = new WebService::GData::ClientLogin(
-           email=>...@gmail.com',
+           email=>'...@gmail.com',
            password=>'...',
            key=>KEY
        );
@@ -922,121 +933,16 @@ Example:
        $comment->save;
        
     #instantiate a video
-    my $video = $yt->video;   
+    my $video = $yt->video;  
+     
        $video->title('Live at Shibuya tonight');
        $video->description('Live performance by 6 local bands.');
        $video->keywords('music','live','shibuya','tokyo');
        $video->category('Music');
     #etc
          
-
 =back
 
-=head3 get_user_videos
-
-=over
-
-Get the videos for the logged in user or for the user name you specified.
-
-B<Parameters>
-
-=over 4
-
-=item C<user_name:Scalar> (optional) - the user name/channel name
-
-=back
-
-B<Returns>
-
-=over 4 
-
-=item L<WebService::GData::YouTube::Feed::Video> objects 
-
-=back
-
-B<Throws>
-
-=over 4
-
-=item L<WebService::GData::Error> 
-
-=back
-
-Example:
-
-    use WebService::GData::Base;
-
-    my $auth = new WebService::GData::ClientLogin(email=>...);
-    
-    my $yt   = new WebService::GData::YouTube($auth);
-    
-    my $videos = $yt->get_user_videos();
-
-    #if not logged in, pass the user name as the first parameter
-    my $videos = $yt->get_user_videos('live');
-
-=back
-
-
-=head3 get_user_favorite_videos
-
-Get the videos that user specificly set a favorites (meaning that you may not have write access to the content even if you are logged in!).
-
-B<Parameters>
-
-=over 4
-
-=item C<user_name:Scalar> (optional) - the user name/channel name
-
-=back
-
-B<Returns>
-
-=over
-
-=item L<WebService::GData::YouTube::Feed::Video> objects 
-
-=back
-
-B<Throws>
-
-=over 4
-
-=item L<WebService::GData::Error> 
-
-=back
-
-Example:
-
-    use WebService::GData::Base;
-
-    my $auth = new WebService::GData::ClientLogin(email=>...);
-    
-    my $yt   = new WebService::GData::YouTube($auth);
-    
-    my $videos = $yt->get_user_favorite_videos();
-
-    #if not logged in, pass the user name as the first parameter
-    my $videos = $yt->get_user_favorite_videos('live');
-
-=back
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 
 
 =head2 USER PLAYLIST METHODS
